@@ -732,9 +732,6 @@ def get_reference_sl(metadata, settings):
      # create figure
     fig, ax = plt.subplots(1,1, figsize=[18,9], tight_layout=True)
     mng = plt.get_current_fig_manager()
-    # if shoreline will not be shown to user do not open matplotlib window
-    if settings['check_detection'] == True:
-        mng.window.showMaximized()
     # loop trhough the images
     for i in range(len(filenames)):
         # read image
